Skip to contents

This function reads the bundled package config and returns it. If a local config yaml exists, only supported user-editable settings are merged into the returned config.

Usage

get_config(config_path = NULL)

Arguments

config_path

optional path to a local config yaml. If NULL, uses the path returned by get_config_path().

Value

list containing config items

Examples

cfg <- get_config()