This function checks for an environment variable
CARNATION_CONFIG_YAML to specify the local config yaml path.
If the variable is not set, a default path in the home directory is used.
This function checks for an environment variable
CARNATION_CONFIG_YAML to specify the local config yaml path.
If the variable is not set, a default path in the home directory is used.