This function reads the bundled package config and returns it. If a local config yaml exists, only supported user-editable settings are merged into the returned config.
Arguments
- config_path
optional path to a local config yaml. If
NULL, uses the path returned byget_config_path().